@@ -651,16 +651,27 @@ class Commands(object):
 
         :param args: argparse arguments provided by the user
         """
-
         if args.bootstrap_image:
             args.bootstrap = 'image'
         owner, copr, chroot = self.parse_chroot_path(args.coprchroot)
+
+        with_opts = None
+        if args.rpmbuild_with:
+            with_opts = ' '.join(args.rpmbuild_with)
+
+        without_opts = None
+        if args.rpmbuild_without:
+            without_opts = ' '.join(args.rpmbuild_without)
+
         self.client.project_chroot_proxy.edit(
             ownername=owner, projectname=copr, chrootname=chroot,
             comps=args.upload_comps, delete_comps=args.delete_comps,
             additional_packages=args.packages, additional_repos=args.repos,
-            bootstrap=args.bootstrap, bootstrap_image=args.bootstrap_image,
+            additional_modules=args.modules, with_opts=with_opts,
+            without_opts=without_opts, bootstrap=args.bootstrap,
+            bootstrap_image=args.bootstrap_image,
             isolation=args.isolation,
+            reset_fields=args.reset,
         )
         print("Edit chroot operation was successful.")
 
@@ -674,9 +685,9 @@ class Commands(object):
         project_chroot = self.client.project_chroot_proxy.get(
             ownername=owner, projectname=copr, chrootname=chroot
         )
-        fields = ["additional_packages", "additional_repos", "comps_name", "delete_after_days",
-                  "isolation", "mock_chroot", "ownername", "projectname", "with_opts",
-                  "without_opts"]
+        fields = ["additional_packages", "additional_repos", "additional_modules",
+                  "comps_name", "delete_after_days", "isolation", "mock_chroot",
+                  "ownername", "projectname", "with_opts", "without_opts"]
         printer = get_printer(args.output_format, fields)
         printer.add_data(project_chroot)
         printer.finish()
@@ -1404,7 +1415,13 @@ def setup_parser():
                                       help="space separated string of package names to be added to buildroot")
     parser_edit_chroot.add_argument("--repos",
                                       help="space separated string of additional repo urls for chroot")
-    parser_edit_chroot.add_argument("--isolation", choices=["simple", "nspawn", "default"], default="unchanged",
+    parser_edit_chroot.add_argument("--modules",
+                                      help="comma separated list of modules that will be enabled or disabled in the given chroot, e.g. 'module1:stream,!module2:stream'")
+    parser_edit_chroot.add_argument("--rpmbuild-with", action='append',
+                                      help="rpmbuild --with option, can be set multiple times")
+    parser_edit_chroot.add_argument("--rpmbuild-without", action='append',
+                                      help="rpmbuild --without options, can be set multiple times")
+    parser_edit_chroot.add_argument("--isolation", choices=["simple", "nspawn", "default"],
                                     help="Choose the isolation method for running commands in buildroot.")
 
     parser_edit_chroot.add_argument(
@@ -1422,6 +1439,15 @@ def setup_parser():
         help=("Use a custom container image for initializing Mock's "
               "bootstrap (Implies --bootstrap=image)"))
 
+    parser_edit_chroot.add_argument(
+        "--reset",
+        action="append",
+        help=("Reset this parameters to their respective defaults. "
+              "Possible values are additional_packages, additional_modules, "
+              "isolation, etc. See the output of `copr-cli get-chroot' for all "
+              "the possible field names."),
+    )
+
     parser_edit_chroot.set_defaults(func="action_edit_chroot")
 
     parser_get_chroot = subparsers.add_parser("get-chroot", help="Get chroot of a project")
